@@ -23,6 +23,7 @@
 #include "cdd_f.h"
 #include <Rinternals.h>
 #include "mycddio_f.h"
+#include <string.h>
 
 SEXP scdd_f(SEXP m, SEXP h, SEXP roworder, SEXP adjacency,
     SEXP inputadjacency, SEXP incidence, SEXP inputincidence)
@@ -125,7 +126,7 @@ SEXP scdd_f(SEXP m, SEXP h, SEXP roworder, SEXP adjacency,
         }
 
     ddf_RowOrderType strategy = ddf_LexMin;
-    char *row_str = CHAR(STRING_ELT(roworder, 0));
+    const char *row_str = CHAR(STRING_ELT(roworder, 0));
     if(strcmp(row_str, "maxindex") == 0)
         strategy = ddf_MaxIndex;
     else if(strcmp(row_str, "minindex") == 0)
